import { select, csv, scaleLinear, max, scalePoint, axisLeft, axisBottom, format, extent, min } from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

//    d.mpg = +d.mpg;
//    d.cylinders = +d.cylinders;
//   d.displacement = +d.displacement;
//    d.horsepower = +d.horsepower;
//    d.weight = +d.weight;
//    d.acceleration = +d.acceleration;
//    d.year = +d.year;

const render = data => {
  
  const xValue = d=> d.horsepower;
  const yValue = d => d.weight;
  const margin = { top: 50, right: 60, bottom: 80, left: 100 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const xlabel = 'HorsePower';
  
  const xScale = scaleLinear()
  	.domain(extent(data,xValue))
  	.range([0, innerWidth])
  	.nice();
  

  
  const yScale = scaleLinear()
  	.domain([min(data,yValue),max(data,yValue)])
  	.range([0, innerHeight]);
  
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
    const xAxisTickFormat = number => 
  	format('.3s')(number)
  		.replace('G','B');
  
  const xAxis = axisBottom(xScale)
  	.tickFormat(xAxisTickFormat)
  	.tickSize(-innerHeight);
  
  const yAxis = axisLeft(yScale)
  		.tickSize(-innerWidth);

  
  g.append('g')
    .call(yAxis)
  	.selectAll('.domain')
  		.remove();
  console.log("yAXIS " + yAxis);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  console.log(yScale.domain());
  console.log(xScale.range());
   
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx',d => xScale(xValue(d)))
  		.attr('r',8);
  
  xAxisG.append('text')
  	.attr('class','axis-label')
  	.text(xlabel)
  	.attr('y', 50)
  	.attr('x', innerWidth / 2)
  	.attr('fill','black');
  
  g.append('text')
  	.attr('class','title')
  	.attr('y',-10)
  	.text('Top 10 Most Populous Countries');
};

csv('https://vizhub.com/curran/datasets/auto-mpg.csv').then(data => {
  data.forEach(d => {
    d.mpg = +d.mpg;
    d.cylinders = +d.cylinders;
    d.displacement = +d.displacement;
    d.horsepower = +d.horsepower;
    d.weight = +d.weight;
    d.acceleration = +d.acceleration;
    d.year = +d.year;
  });
  render(data);
});